// utils/cache.js

/**
 * 引入缓存工具
 * const Cache = require('/utils/cache.js');
 * 设置缓存，5分钟后过期
 * Cache.set('userInfo', { name: 'John Doe', age: 30 }, 300);
 * 获取缓存
 * const userInfo = Cache.get('userInfo');
 * console.log('用户信息:', userInfo);
 * 删除缓存
 * Cache.remove('userInfo');
 * 清空所有缓存
 * Cache.clear();
 */
const Cache = {
    /**
     * 设置缓存
     * @param {string} key 缓存键
     * @param {*} value 缓存值
     * @param {number} [expire] 过期时间（秒），可选
     */
    set(key, value, expire) {
      const data = {
        value,
        expire: expire ? Date.now() + expire * 1000 : null, // 如果有过期时间，记录到期时间戳
      };
      try {
        wx.setStorageSync(key, data);
      } catch (e) {
        console.error(`设置缓存失败: ${e.message}`);
      }
    },
  
    /**
     * 获取缓存
     * @param {string} key 缓存键
     * @returns {*} 缓存值或null
     */
    get(key) {
      try {
        const data = wx.getStorageSync(key);
        if (!data) return null;
  
        // 判断是否过期
        if (data.expire && data.expire < Date.now()) {
          wx.removeStorageSync(key); // 清理过期数据
          return null;
        }
        return data.value;
      } catch (e) {
        console.error(`获取缓存失败: ${e.message}`);
        return null;
      }
    },
  
    /**
     * 删除指定缓存
     * @param {string} key 缓存键
     */
    remove(key) {
      try {
        wx.removeStorageSync(key);
      } catch (e) {
        console.error(`删除缓存失败: ${e.message}`);
      }
    },
  
    /**
     * 清空所有缓存
     */
    clear() {
      try {
        wx.clearStorageSync();
      } catch (e) {
        console.error(`清空缓存失败: ${e.message}`);
      }
    },
  };
  
  module.exports = Cache;
  